@@ -132,6 +132,7 @@ class MainWindow(object):
         self.export_assistant = ExportAssistant(self.journal)
         self.export_assistant.set_transient_for(self.main_frame)
 
+        self.setup_clouds()
         self.setup_search()
         self.setup_insert_menu()
         self.setup_format_menu()
@@ -149,17 +150,11 @@ class MainWindow(object):
             'on_main_frame_window_state_event': self.on_main_frame_window_state_event,
 
             'on_add_new_entry_button_clicked': self.on_add_new_entry_button_clicked,
-            'on_add_tag_button_clicked': self.on_add_tag_button_clicked,
-
-            'on_search_notebook_switch_page': self.on_search_notebook_switch_page,
 
             'on_template_button_clicked': self.on_template_button_clicked,
             'on_template_menu_show_menu': self.on_template_menu_show_menu,
             'on_template_menu_clicked': self.on_template_menu_clicked,
 
-            'on_search_type_box_changed': self.on_search_type_box_changed,
-            'on_cloud_combo_box_changed': self.on_cloud_combo_box_changed,
-
             'on_main_frame_delete_event': self.on_main_frame_delete_event,
 
             # connect_signals can only be called once, it seems
@@ -167,7 +162,6 @@ class MainWindow(object):
              }
         self.builder.connect_signals(dic)
 
-        self.setup_clouds()
         self.set_shortcuts()
         self.setup_stats_dialog()
 
@@ -228,8 +222,8 @@ class MainWindow(object):
         #   self.day_text_field.day_text_view.add_accelerator(signal, self.accel_group,
         #                   ord(key), gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
 
-        shortcuts = [(self.back_one_day_button, 'clicked', '<Ctrl>Page_Down'),
-                    (self.forward_one_day_button, 'clicked', '<Ctrl>Page_Up'),
+        shortcuts = [(self.back_one_day_button, 'clicked', '<Ctrl>Page_Up'),
+                    (self.forward_one_day_button, 'clicked', '<Ctrl>Page_Down'),
                     #(self.builder.get_object('undo_menuitem'), 'activate', '<Ctrl>z'),
                     #(self.builder.get_object('redo_menuitem'), 'activate', '<Ctrl>y'),
                     #(self.builder.get_object('options_menuitem'), 'activate', '<Ctrl><Alt>p'),
@@ -393,47 +387,17 @@ class MainWindow(object):
 
 
     def setup_search(self):
-        self.search_notebook = self.builder.get_object('search_notebook')
-
-        self.search_tree_view = search.SearchTreeView(self.builder.get_object(
-                                    'search_tree_view'), self)
-        self.search_type_box = self.builder.get_object('search_type_box')
-        self.search_type_box.set_active(0)
+        self.search_tree_view = search.SearchTreeView(self)
+        self.search_tree_view.show()
+        scroll = gtk.ScrolledWindow()
+        scroll.add(self.search_tree_view)
+        self.builder.get_object('search_container').pack_start(scroll)
         self.search_box = search.SearchComboBox(self.builder.get_object(
-                            'search_box'), self)
-
-
-    def on_search_type_box_changed(self, widget):
-        search_type = widget.get_active()
-        self.search_box.set_search_type(search_type)
-
-
-    def on_search_notebook_switch_page(self, notebook, page, page_number):
-        '''
-        Called when the page actually changes
-        '''
-        if page_number == 0:
-            # Switched to search tab
-            #self.search_tree_view.update_data()
-
-            # Put cursor into search field, when search tab is opened
-            gobject.idle_add(self.search_box.entry.grab_focus)
-        if page_number == 1:
-            # Switched to cloud tab
-            self.cloud.update(force_update=True)
+                                                        'search_box'), self)
 
     def setup_clouds(self):
-        self.cloud_box = self.builder.get_object('cloud_box')
         self.cloud = Cloud(self.journal)
-
-        self.cloud_box.pack_start(self.cloud)
-
-        self.cloud_combo_box = self.builder.get_object('cloud_combo_box')
-        self.cloud_combo_box.set_active(0)
-
-    def on_cloud_combo_box_changed(self, cloud_combo_box):
-        value_int = cloud_combo_box.get_active()
-        self.cloud.set_type(value_int)
+        self.builder.get_object('search_container').pack_start(self.cloud)
 
     def on_main_frame_configure_event(self, widget, event):
         '''
@@ -512,14 +476,13 @@ class MainWindow(object):
                 self.journal.dirs.data_dir = dir
                 self.journal.save_to_disk(saveas=True)
 
-            load_files = type in ['open', 'saveas']
-            self.journal.open_journal(dir, load_files=load_files)
+            self.journal.open_journal(dir)
 
         # If the dir was not found previously, we have nothing to open
         # if the user selects "Abort". So select default dir and show message
         elif dir_not_found:
             default_dir = self.journal.dirs.default_data_dir
-            self.journal.open_journal(default_dir, load_files=True)
+            self.journal.open_journal(default_dir)
             ### Translators: The default journal is located at $HOME/.rednotebook/data
             self.journal.show_message(_('The default journal has been opened'))
 
@@ -560,8 +523,6 @@ class MainWindow(object):
         # Remember window position
         config['mainFrameX'], config['mainFrameY'] = self.main_frame.get_position()
 
-        config['cloudTabActive'] = self.search_notebook.get_current_page()
-
         # Actually this is unnecessary as the list gets saved when it changes
         # so we use it to sort the list ;)
         config.write_list('cloudIgnoreList', sorted(self.cloud.ignore_list))
@@ -670,17 +631,27 @@ class MainWindow(object):
             markup = format_to_markup[format]
 
             focus = self.main_frame.get_focus()
+            iter = self.categories_tree_view.get_selected_node()
 
-
-            if focus == self.categories_tree_view.tree_view:
-                iter = self.categories_tree_view.get_selected_node()
-                if iter:
-                    text = self.categories_tree_view.get_iter_value(iter)
-                    text = '%s%s%s' % (markup, text, markup)
-                    self.categories_tree_view.set_iter_value(iter, text)
-                    return
-            #if focus is None or focus == self.day_text_field.day_text_view:
-            self.day_text_field.apply_format(format, markup)
+            if isinstance(focus, gtk.Entry):
+                entry = focus
+                pos = entry.get_position()
+                # bounds can be an empty tuple
+                bounds = entry.get_selection_bounds() or (pos, pos)
+                selected_text = entry.get_chars(*bounds).decode('utf-8')
+                entry.delete_text(*bounds)
+                entry.insert_text('%s%s%s' % (markup, selected_text, markup), bounds[0])
+                # Set cursor after the end of the formatted text
+                entry.set_position(bounds[0] + len(markup) + len(selected_text))
+            elif focus == self.categories_tree_view.tree_view and iter:
+                text = self.categories_tree_view.get_iter_value(iter)
+                text = '%s%s%s' % (markup, text, markup)
+                self.categories_tree_view.set_iter_value(iter, text)
+            elif focus == self.day_text_field.day_text_view:
+                self.day_text_field.apply_format(format, markup)
+            else:
+                self.journal.show_message(_('No text or tag has been selected.'),
+                                          error=True)
 
         def shortcut(char):
             ### Translators: The Control (Ctrl) key
@@ -707,7 +678,7 @@ class MainWindow(object):
         self.format_toolbutton = gtk.MenuToolButton(gtk.STOCK_BOLD)
         ### Translators: noun
         self.format_toolbutton.set_label(_('Format'))
-        tip = _('Format the selected text or category entry')
+        tip = _('Format the selected text or tag')
         self.format_toolbutton.set_tooltip_text(tip)
         self.format_toolbutton.set_menu(menu)
         bold_func = apply_format#lambda widget: self.day_text_field.apply_format('bold')
@@ -867,7 +838,9 @@ class MainWindow(object):
         filter.add_mime_type("image/gif")
         filter.add_pattern("*.png")
         filter.add_pattern("*.jpg")
+        filter.add_pattern("*.jpeg")
         filter.add_pattern("*.gif")
+        filter.add_pattern("*.bmp")
 
         picture_chooser.add_filter(filter)
 
@@ -926,9 +899,6 @@ class MainWindow(object):
     def on_add_new_entry_button_clicked(self, widget):
         self.categories_tree_view._on_add_entry_clicked(None)
 
-    def on_add_tag_button_clicked(self, widget):
-        self.new_entry_dialog.show_dialog(category='Tags')
-
     def set_date(self, new_month, new_date, day):
         self.categories_tree_view.clear()
 
@@ -1053,14 +1023,13 @@ class NewEntryDialog(object):
         self.dialog.set_response_sensitive(gtk.RESPONSE_OK, self._text_entered())
 
     def _text_entered(self):
-        return bool(self.categories_combo_box.get_active_text() and
-                self.new_entry_combo_box.get_active_text())
+        return bool(self.categories_combo_box.get_active_text())
 
     def show_dialog(self, category=''):
         # Has to be first, because it may be populated later
         self.new_entry_combo_box.clear()
 
-        # Show the list of categories even if adding a tag
+        # Show the list of categories
         self.categories_combo_box.set_entries(self.categories_tree_view.categories)
 
         if category:
@@ -1083,8 +1052,6 @@ class NewEntryDialog(object):
             return
 
         entry_text = self.new_entry_combo_box.get_active_text()
-        if not self.categories_tree_view.check_entry(entry_text):
-            return
 
         self.categories_tree_view.add_entry(category_name, entry_text)
 
