@@ -22,12 +22,12 @@ from __future__ import with_statement
 import sys
 import datetime
 import os
-import collections
 import time
 import itertools
 import logging
 import locale
-from optparse import OptionParser, OptionValueError
+from optparse import OptionParser
+from collections import defaultdict
 
 
 # Use basic stdout logging before we can initialize logging correctly
@@ -212,8 +212,6 @@ class Journal:
         self.config = user_config
         self.config.save_state()
 
-        self.warn_if_second_instance()
-
         logging.info('Running in portable mode: %s' % self.dirs.portable)
 
         self.testing = False
@@ -263,28 +261,6 @@ class Journal:
         if not self.testing:
             gobject.timeout_add_seconds(600, self.save_to_disk)
 
-    def warn_if_second_instance(self):
-        '''Show warning when a second instance is started'''
-        running = self.config.read('running', 0)
-        if running:
-            logging.warning('RedNotebook instance already running')
-            text1 = _('RedNotebook appears to be already running.')
-            text2 = _('This can happen if the application is hidden in the '
-                      'system tray or was not shut down correctly.')
-            text3 = _('Starting a second RedNotebook instance can lead to data '
-                      'loss and it might be best to see if there is another '
-                      'instance first.')
-            text4 = _('Do you want to start a new RedNotebook instance nevertheless?')
-            dialog = gtk.MessageDialog(type=gtk.MESSAGE_WARNING,
-                                       buttons=gtk.BUTTONS_YES_NO, message_format=text1)
-            dialog.format_secondary_text('%s %s\n\n%s' % (text2, text3, text4))
-            answer = dialog.run()
-            dialog.hide()
-            if not answer == gtk.RESPONSE_YES:
-                sys.exit()
-        self.config['running'] = 1
-        self.config.save_to_disk()
-
 
     def get_journal_path(self):
         '''
@@ -333,6 +309,9 @@ class Journal:
 
         if self.is_allowed_to_exit:
             logging.info('Goodbye!')
+            # Informs the logging system to perform an orderly shutdown by
+            # flushing and closing all handlers.
+            logging.shutdown()
             gtk.main_quit()
 
 
@@ -371,7 +350,7 @@ class Journal:
         return True
 
 
-    def open_journal(self, data_dir, load_files=True):
+    def open_journal(self, data_dir):
 
         if self.months:
             self.save_to_disk(changing_journal=True)
@@ -390,11 +369,7 @@ class Journal:
 
         data_dir_empty = not os.listdir(data_dir)
 
-        if not load_files and not data_dir_empty:
-            msg_part1 = _('The selected folder is not empty.')
-            msg_part2 = _('To prevent you from overwriting data, the folder content has been imported into the new journal.')
-            self.show_message('%s %s' % (msg_part1, msg_part2), error=False)
-        elif load_files and data_dir_empty:
+        if data_dir_empty:
             self.show_message(_('The selected folder is empty. A new journal has been created.'),
                                 error=False)
 
@@ -403,9 +378,7 @@ class Journal:
         self.month = None
         self.months.clear()
 
-        # We always want to load all files
-        if load_files or True:
-            self.months = storage.load_all_months_from_disk(data_dir)
+        self.months = storage.load_all_months_from_disk(data_dir)
 
         # Nothing to save before first day change
         self.load_day(self.actual_date)
@@ -414,22 +387,10 @@ class Journal:
 
         self.frame.categories_tree_view.categories = self.categories
 
-        if self.is_first_start:
+        if self.is_first_start and data_dir_empty and len(self.days) == 0:
             self.add_instruction_content()
 
-        # Notebook is only on page 1 here, if we are opening a journal the second time
-        old_page = self.frame.search_notebook.get_current_page()
-        new_page = self.config.read('cloudTabActive', 0)
-        # 0 -> 0: search is cleared later
-        # 0 -> 1: change to cloud, update automatically
-        # 1 -> 0: change to search
-        # 1 -> 1: update cloud
-
-        # At tab change, cloud is updated automatically
-        self.frame.search_notebook.set_current_page(new_page)
-        if new_page == old_page:
-            # Without tab change, force update
-            self.frame.cloud.update(force_update=True)
+        self.frame.cloud.update(force_update=True)
 
         # Reset Search
         self.frame.search_box.clear()
@@ -543,11 +504,6 @@ class Journal:
                            key=utils.sort_asc))
 
 
-    @property
-    def tags(self):
-        return self.get_entries('Tags')
-
-
     def get_entries(self, category):
         entries = set()
         for day in self.days:
@@ -555,26 +511,25 @@ class Journal:
         return sorted(entries)
 
 
-    def search(self, text=None, category=None, tag=None):
+    def search(self, text):
         results = []
         for day in reversed(self.days):
-            result = None
-            if text:
-                result = day.search_text(text)
-            elif category:
-                result = day.search_category(category)
-            elif tag:
-                result = day.search_tag(tag)
-
-            if result:
-                if category:
-                    results.extend(result)
-                else:
-                    results.append(result)
-
+            results.append(day.search(text))
         return results
 
 
+    def get_word_count_dict(self):
+        '''
+        Returns a dictionary mapping the words to their number of appearance
+        '''
+        word_dict = defaultdict(int)
+        for day in self.days:
+            words = day.get_words()
+            for word in words:
+                word_dict[word.lower()] += 1
+        return word_dict
+
+
     @property
     def days(self):
         '''
@@ -597,24 +552,6 @@ class Journal:
         return days
 
 
-    def get_word_count_dict(self, type):
-        '''
-        Returns a dictionary mapping the words to their number of appearance
-        '''
-        word_dict = collections.defaultdict(int)
-        for day in self.days:
-            if type == 'word':
-                words = day.get_words()
-            if type == 'category':
-                words = day.categories
-            if type == 'tag':
-                words = day.tags
-
-            for word in words:
-                word_dict[word.lower()] += 1
-        return word_dict
-
-
     def get_days_in_date_range(self, start_date=None, end_date=None):
         if not start_date:
             start_date = datetime.date.min
@@ -635,17 +572,8 @@ class Journal:
         return days_in_date_range
 
 
-    def go_to_first_empty_day(self):
-        if len(self.days) == 0:
-            return datetime.date.today()
-
-        last_edited_day = self.days[-1]
-        first_empty_date = last_edited_day.date + dates.one_day
-        self.change_date(first_empty_date)
-
-
     def add_instruction_content(self):
-        self.go_to_first_empty_day()
+        self.change_date(datetime.date.today())
         current_date = self.date
 
         logging.info('Adding example content on %s' % current_date)
@@ -669,8 +597,6 @@ def main():
     try:
         logging.debug('Trying to enter the gtk main loop')
         gtk.main()
-        #logging.debug('Closing logfile')
-        #file_logging_stream.close()
     except KeyboardInterrupt:
         # 'Interrupt'
         #journal.save_to_disk()
