@@ -19,7 +19,6 @@
 
 from __future__ import with_statement
 
-import os
 import logging
 import re
 import sys
@@ -34,26 +33,73 @@ if __name__ == '__main__':
                     format='%(levelname)-8s %(message)s',)
 
 from rednotebook.external import txt2tags
-from rednotebook.util import filesystem
 
 
 # Linebreaks are only allowed at line ends
 REGEX_LINEBREAK = r'\\\\[\s]*$'
 REGEX_HTML_LINK = r'<a.*?>(.*?)</a>'
 
+TABLE_HEAD_BG = '#aaa'
+BLOCKQUOTE_BG = '#ccc'
+
+CHARSET_UTF8 = '<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />'
+
 CSS = """\
 <style type="text/css">
     body {
-        font-family: Ubuntu, sans-serif;
+        font-family: Ubuntu, Helvetica, Arial, sans-serif;
+    }
+    blockquote {
+        margin: 1em 2em;
+        border-left: 2px solid #999;
+        font-style: oblique;
+        padding-left: 1em;
+    }
+    blockquote:first-letter {
+        margin: .2em .1em .1em 0;
+        font-size: 160%%;
+        font-weight: bold;
+    }
+    blockquote:first-line {
+        font-weight: bold;
+    }
+    table {
+        border-collapse: collapse;
+    }
+    td, th {
+        <!--border: 1px solid #888;--> <!--Allow tables without borders-->
+        padding: 3px 7px 2px 7px;
+    }
+    th {
+        text-align: left;
+        padding-top: 5px;
+        padding-bottom: 4px;
+        background-color: %(TABLE_HEAD_BG)s;
+        color: #ffffff;
+    }
+    hr.heavy {
+        height: 2px;
+        background-color: black;
     }
 </style>
+""" % globals()
+
+MATHJAX = """\
+<script type="text/x-mathjax-config">
+MathJax.Hub.Config({
+  tex2jax: {inlineMath: [['$','$']]}
+});
+</script>
+<script type="text/javascript"
+  src="https://d3eoax9i5htok0.cloudfront.net/mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML">
+</script>
 """
 
 
 def convert_categories_to_markup(categories, with_category_title=True):
-    'Only add Category title if the text is displayed'
+    # Only add Category title if the text is displayed
     if with_category_title:
-        markup = '== %s ==\n' % _('Categories')
+        markup = '== %s ==\n' % _('Tags')
     else:
         markup = ''
 
@@ -122,18 +168,24 @@ def _get_config(type):
     config['preproc'] = []
 
     # Allow line breaks, r'\\\\' are 2 \ for regexes
-    config['preproc'].append([REGEX_LINEBREAK, 'REDNOTEBOOKLINEBREAK'])
+    config['preproc'].append([REGEX_LINEBREAK, 'LINEBREAK'])
 
     if type == 'xhtml' or type == 'html':
         config['encoding'] = 'UTF-8'  # document encoding
         config['toc'] = 0
         config['css-sugar'] = 1
 
+        # Fix encoding for export opened in firefox
+        config['postproc'].append([r'<head>', '<head>' + CHARSET_UTF8])
+
         # Custom css
         config['postproc'].append([r'</head>', CSS + '</head>'])
 
+        # mathjax
+        #config['postproc'].append([r'</body>', MATHJAX + '</body>'])
+
         # Line breaks
-        config['postproc'].append([r'REDNOTEBOOKLINEBREAK', '<br />'])
+        config['postproc'].append([r'LINEBREAK', '<br />'])
 
         # Apply image resizing
         config['postproc'].append([r'src=\"WIDTH(\d+)-', r'width="\1" src="'])
@@ -162,14 +214,18 @@ def _get_config(type):
                                    r'htmladdnormallink{\1}{run:\2}'])
 
         # Line breaks
-        config['postproc'].append([r'REDNOTEBOOKLINEBREAK', r'\\\\'])
+        config['postproc'].append([r'LINEBREAK', r'\\\\'])
 
         # Apply image resizing
         config['postproc'].append([r'includegraphics\{("?)WIDTH(\d+)-', r'includegraphics[width=\2px]{\1'])
 
+        # We want the plain latex formulas unescaped
+        config['preproc'].append([r'\$\s*(.+?)\s*\$', r"BEGINFORMULA''\1''ENDFORMULA"])
+        config['postproc'].append([r'BEGINFORMULA(.+)ENDFORMULA', r'$\1$'])
+
     elif type == 'txt':
         # Line breaks
-        config['postproc'].append([r'REDNOTEBOOKLINEBREAK', '\n'])
+        config['postproc'].append([r'LINEBREAK', '\n'])
 
         # Apply image resizing ([WIDTH400-file:///pathtoimage.jpg])
         config['postproc'].append([r'\[WIDTH(\d+)-(.+)\]', r'[\2?\1]'])
@@ -315,3 +371,10 @@ def convert_from_pango(pango_markup):
     logging.log(5, 'Converted "%s" pango to "%s" txt2tags' %
                 (repr(original_txt), repr(pango_markup)))
     return pango_markup
+
+
+if __name__ == '__main__':
+    from rednotebook.util.utils import show_html_in_browser
+    markup = 'Aha\n\tThis is a quote. It looks very nice. Even with many lines'
+    html = convert(markup, 'xhtml')
+    show_html_in_browser(html, '/tmp/test.html')
